==> zio-aws-appmesh_2.13-5.17.182.1-sources.jar: zio/aws/appmesh/model/DnsServiceDiscovery.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.appmesh.model.primitives.Hostname
import scala.jdk.CollectionConverters._
final case class DnsServiceDiscovery(
    hostname: Hostname,
    responseType: Optional[zio.aws.appmesh.model.DnsResponseType] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.DnsServiceDiscovery = {
    import DnsServiceDiscovery.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.DnsServiceDiscovery
      .builder()
      .hostname(Hostname.unwrap(hostname): java.lang.String)
      .optionallyWith(responseType.map(value => value.unwrap))(_.responseType)
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.DnsServiceDiscovery.ReadOnly =
    zio.aws.appmesh.model.DnsServiceDiscovery.wrap(buildAwsValue())
}
object DnsServiceDiscovery {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.DnsServiceDiscovery
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.DnsServiceDiscovery =
      zio.aws.appmesh.model
        .DnsServiceDiscovery(hostname, responseType.map(value => value))
    def hostname: Hostname
    def responseType: Optional[zio.aws.appmesh.model.DnsResponseType]
    def getHostname: ZIO[Any, Nothing, Hostname] = ZIO.succeed(hostname)
    def getResponseType
        : ZIO[Any, AwsError, zio.aws.appmesh.model.DnsResponseType] =
      AwsError.unwrapOptionField("responseType", responseType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.DnsServiceDiscovery
  ) extends zio.aws.appmesh.model.DnsServiceDiscovery.ReadOnly {
    override val hostname: Hostname =
      zio.aws.appmesh.model.primitives.Hostname(impl.hostname())
    override val responseType: Optional[zio.aws.appmesh.model.DnsResponseType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.responseType())
        .map(value => zio.aws.appmesh.model.DnsResponseType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.DnsServiceDiscovery
  ): zio.aws.appmesh.model.DnsServiceDiscovery.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appmesh_3-5.17.104.3-sources.jar: zio/aws/appmesh/model/DnsServiceDiscovery.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.appmesh.model.primitives.Hostname
import scala.jdk.CollectionConverters.*
final case class DnsServiceDiscovery(
    hostname: Hostname,
    responseType: Option[zio.aws.appmesh.model.DnsResponseType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.DnsServiceDiscovery = {
    import DnsServiceDiscovery.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.DnsServiceDiscovery
      .builder()
      .hostname(Hostname.unwrap(hostname): java.lang.String)
      .optionallyWith(responseType.map(value => value.unwrap))(_.responseType)
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.DnsServiceDiscovery.ReadOnly =
    zio.aws.appmesh.model.DnsServiceDiscovery.wrap(buildAwsValue())
}
object DnsServiceDiscovery {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.DnsServiceDiscovery
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.DnsServiceDiscovery =
      zio.aws.appmesh.model
        .DnsServiceDiscovery(hostname, responseType.map(value => value))
    def hostname: Hostname
    def responseType: Option[zio.aws.appmesh.model.DnsResponseType]
    def getHostname: ZIO[Any, Nothing, Hostname] = ZIO.succeed(hostname)
    def getResponseType
        : ZIO[Any, AwsError, zio.aws.appmesh.model.DnsResponseType] =
      AwsError.unwrapOptionField("responseType", responseType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.DnsServiceDiscovery
  ) extends zio.aws.appmesh.model.DnsServiceDiscovery.ReadOnly {
    override val hostname: Hostname =
      zio.aws.appmesh.model.primitives.Hostname(impl.hostname())
    override val responseType: Option[zio.aws.appmesh.model.DnsResponseType] =
      scala
        .Option(impl.responseType())
        .map(value => zio.aws.appmesh.model.DnsResponseType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.DnsServiceDiscovery
  ): zio.aws.appmesh.model.DnsServiceDiscovery.ReadOnly = new Wrapper(impl)
}
